=============================================
MontePetro - Probabilistic Reserves in Python
=============================================
.. image:: https://api.travis-ci.org/z4r/python-coveralls.png?branch=master
    :target: http://travis-ci.org/LukasMosser/MontePetro
.. image:: https://coveralls.io/repos/LukasMosser/MontePetro/badge.png?branch=master
    :target: https://coveralls.io/r/LukasMosser/MontePetro?branch=master

Coming soon...
